from distutils.core import setup

setup(
		name = 'ml_nester',
		version = '1.1.0',
		py_modules = ['nester'],
		author = 'MagnusLislevatn',
		author_email = 'magnus.lislevatn@gmail.com',
		url = 'http://magnuslisleva.tn',
		description = 'A simple printer of nested lists',
	)
